@@ -613,6 +613,7 @@ go_to_server_cb (NautilusWindow *window,
 			g_bookmark_file_to_file (bookmarks, filename, NULL);
 		}
 
+		nautilus_file_unref (file);
 		g_free (filename);
 		g_bookmark_file_free (bookmarks);
 
@@ -1152,6 +1153,56 @@ init_gtk_accels (void)
 	g_free (old_scripts_directory_path);
 }
 
+static void
+theme_changed (GtkSettings *settings)
+{
+	static GtkCssProvider *provider = NULL;
+	gchar *theme;
+	GdkScreen *screen;
+
+	g_object_get (settings, "gtk-theme-name", &theme, NULL);
+	screen = gdk_screen_get_default ();
+
+	if (g_str_equal (theme, "Adwaita"))
+	{
+		if (provider == NULL)
+		{
+			GFile *file;
+
+			provider = gtk_css_provider_new ();
+			file = g_file_new_for_uri ("resource:///org/gnome/nautilus/Adwaita.css");
+			gtk_css_provider_load_from_file (provider, file, NULL);
+			g_object_unref (file);
+		}
+
+		gtk_style_context_add_provider_for_screen (screen,
+							   GTK_STYLE_PROVIDER (provider),
+							   GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	}
+	else if (provider != NULL)
+	{
+		gtk_style_context_remove_provider_for_screen (screen,
+							      GTK_STYLE_PROVIDER (provider));
+		g_clear_object (&provider);
+	}
+
+	g_free (theme);
+}
+
+static void
+setup_theme_extensions (void)
+{
+	GtkSettings *settings;
+
+	/* Set up a handler to load our custom css for Adwaita.
+	 * See https://bugzilla.gnome.org/show_bug.cgi?id=732959
+	 * for a more automatic solution that is still under discussion.
+	 */
+	settings = gtk_settings_get_default ();
+	g_signal_connect (settings, "notify::gtk-theme-name", G_CALLBACK (theme_changed), NULL);
+	theme_changed (settings);
+}
+
 static void
 nautilus_application_startup (GApplication *app)
 {
@@ -1166,6 +1217,8 @@ nautilus_application_startup (GApplication *app)
 
 	gtk_window_set_default_icon_name ("system-file-manager");
 
+	setup_theme_extensions ();
+
 	/* create DBus manager */
 	self->priv->fdb_manager = nautilus_freedesktop_dbus_new ();
 
