@@ -71,7 +71,6 @@ struct NautilusWindowDetails
         gboolean disable_chrome;
 
         guint sidebar_width_handler_id;
-        guint app_menu_visibility_id;
         guint bookmarks_id;
 };
 
@@ -110,7 +109,6 @@ void nautilus_window_sync_up_button        (NautilusWindow *window);
 /* window menus */
 void               nautilus_window_initialize_actions                    (NautilusWindow    *window);
 void               nautilus_window_initialize_menus                      (NautilusWindow    *window);
-void               nautilus_window_finalize_menus                        (NautilusWindow    *window);
 
 void               nautilus_window_update_show_hide_menu_items           (NautilusWindow     *window);
 
